Method: Rubyfb::Backup#initialize

Defined in:
lib/src.rb

#initialize(database, file) ⇒ Backup

This is the constructor for the Backup class.

Parameters

database

A String or File giving the path and name (relative to the database server) of the main database file for the database to be backed up.

file

A String or File giving the path and name (relative to the database server) of the back up file to be generated.



1478
1479
# File 'lib/src.rb', line 1478

def initialize(database, file)
end