Method: Rubyfb::Connection#execute_immediate
- Defined in:
- lib/src.rb
#execute_immediate(sql) {|row| ... } ⇒ Object
This function executes a SQL statement against a connection. This differs from the execute method in that an anonymous transaction is used in executing the statement. The output from this method is the same as for the execute method. The method also accepts a block that takes a single parameter. This block will be executed once for each row in any result set generated.
Parameters
- sql
-
The SQL statement to be executed.
Exceptions
- Exception
-
Generated whenever a problem occurs executing the SQL statement.
360 361 362 |
# File 'lib/src.rb', line 360 def execute_immediate(sql) yield(row) end |