Method: Rubyfb::ResultSet#column_scale

Defined in:
lib/src.rb

#column_scale(column) ⇒ Object

This method fetches the scale associated with a specified column for a ResultSet object. Firebird implements some floating point types with integral storage and a negative scale. For example, depending on your platform

SELECT 1.003 FROM RDB$DATABASE

may return a ResultSet, the first and only column of which has a base type of :BIGINT but a scale of -3. (Fetches of the actual value will correctly return a ruby Float.)

Parameters

column

A reference to the column number to fetch the details for. Column numbers start at zero.



827
828
# File 'lib/src.rb', line 827

def column_scale(column)
end