Class: Rubyfb::Backup
- Inherits:
-
Object
- Object
- Rubyfb::Backup
- Defined in:
- lib/src.rb
Overview
This class represents a service manager task to backup an existing database on the Firebird server. NOTE: This class does not currently work on the Mac OS X platform.
Instance Attribute Summary collapse
-
#backup_file ⇒ Object
Attribute accessor.
-
#database ⇒ Object
Attribute accessor.
Instance Method Summary collapse
-
#blocking_factor ⇒ Object
This method fetches the blocking factor to be used in generating the back up.
-
#blocking_factor=(size) ⇒ Object
This method sets the blocking factor to be used in generating the back up.
-
#convert_tables ⇒ Object
This method fetches the convert tables setting for a Backup object.
-
#convert_tables=(setting) ⇒ Object
This method is used to set the indicator for whether external tables will be converted to internal tables as part of the backup.
-
#execute(manager) ⇒ Object
This method is used to execute a backup task against a service manager.
-
#garbage_collect ⇒ Object
This method fetches the garbage collect setting for a Backup object.
-
#garbage_collect=(setting) ⇒ Object
This method is used to set the indicator for whether the backup will undertake garbage collection.
-
#ignore_checksums ⇒ Object
This method fetches the ignore checksums setting for a Backup object.
-
#ignore_checksums=(setting) ⇒ Object
This method is used to set the indicator for whether checksum values should be ignored in performing a backup.
-
#ignore_limbo ⇒ Object
This method fetches the ignore limbo setting for a Backup object.
-
#ignore_limbo=(setting) ⇒ Object
This method is used to set the indicator for whether limbo transactions should be ignored in performing a backup.
-
#initialize(database, file) ⇒ Backup
constructor
This is the constructor for the Backup class.
-
#log ⇒ Object
This method fetches the log value for a Backup task.
-
#metadata_only ⇒ Object
This method fetches the metadata only setting for a Backup object.
-
#metadata_only=(setting) ⇒ Object
This method is used to set the indicator for whether a backup stores only the database metadata.
-
#non_transportable ⇒ Object
This method fetches the non-transportable setting for a Backup object.
-
#non_transportable=(setting) ⇒ Object
This method is used to set the indicator for whether backup generated by the task will be platform specific.
Constructor Details
#initialize(database, file) ⇒ Backup
This is the constructor for the Backup class.
Parameters
- database
-
A String or File giving the path and name (relative to the database server) of the main database file for the database to be backed up.
- file
-
A String or File giving the path and name (relative to the database server) of the back up file to be generated.
1478 1479 |
# File 'lib/src.rb', line 1478 def initialize(database, file) end |
Instance Attribute Details
#backup_file ⇒ Object
Attribute accessor.
1463 1464 1465 |
# File 'lib/src.rb', line 1463 def backup_file @backup_file end |
#database ⇒ Object
Attribute accessor.
1463 1464 1465 |
# File 'lib/src.rb', line 1463 def database @database end |
Instance Method Details
#blocking_factor ⇒ Object
This method fetches the blocking factor to be used in generating the back up. This will return nil until it has been explicitly set.
1486 1487 |
# File 'lib/src.rb', line 1486 def blocking_factor end |
#blocking_factor=(size) ⇒ Object
This method sets the blocking factor to be used in generating the back up.
Parameters
- size
-
A reference to an integer containing the new back up blocking factor setting.
1498 1499 |
# File 'lib/src.rb', line 1498 def blocking_factor=(size) end |
#convert_tables ⇒ Object
This method fetches the convert tables setting for a Backup object.
1595 1596 |
# File 'lib/src.rb', line 1595 def convert_tables end |
#convert_tables=(setting) ⇒ Object
This method is used to set the indicator for whether external tables will be converted to internal tables as part of the backup.
Parameters
- setting
-
True to convert external tables, false otherwise.
1606 1607 |
# File 'lib/src.rb', line 1606 def convert_tables=(setting) end |
#execute(manager) ⇒ Object
This method is used to execute a backup task against a service manager.
Parameters
- manager
-
A reference to the service manager to execute the backup task against.
Exceptions
- FireRubyException
-
Generated whenever a disconnected service manager is specified or a problem occurs executing the task.
1622 1623 |
# File 'lib/src.rb', line 1622 def execute(manager) end |
#garbage_collect ⇒ Object
This method fetches the garbage collect setting for a Backup object.
1559 1560 |
# File 'lib/src.rb', line 1559 def garbage_collect end |
#garbage_collect=(setting) ⇒ Object
This method is used to set the indicator for whether the backup will undertake garbage collection.
Parameters
- setting
-
True to perform garbage collection, false otherwise.
1570 1571 |
# File 'lib/src.rb', line 1570 def garbage_collect=(setting) end |
#ignore_checksums ⇒ Object
This method fetches the ignore checksums setting for a Backup object.
1505 1506 |
# File 'lib/src.rb', line 1505 def ignore_checksums end |
#ignore_checksums=(setting) ⇒ Object
This method is used to set the indicator for whether checksum values should be ignored in performing a backup.
Parameters
- setting
-
True to ignore checksums, false otherwise.
1516 1517 |
# File 'lib/src.rb', line 1516 def ignore_checksums=(setting) end |
#ignore_limbo ⇒ Object
This method fetches the ignore limbo setting for a Backup object.
1523 1524 |
# File 'lib/src.rb', line 1523 def ignore_limbo end |
#ignore_limbo=(setting) ⇒ Object
This method is used to set the indicator for whether limbo transactions should be ignored in performing a backup.
Parameters
- setting
-
True to ignore limbo transactions, false otherwise.
1534 1535 |
# File 'lib/src.rb', line 1534 def ignore_limbo=(setting) end |
#log ⇒ Object
This method fetches the log value for a Backup task. This value will always be nil until the task has been executed. After a successful execution the log value should contain output from the backup task generated on the server.
1632 1633 |
# File 'lib/src.rb', line 1632 def log end |
#metadata_only ⇒ Object
This method fetches the metadata only setting for a Backup object.
1541 1542 |
# File 'lib/src.rb', line 1541 def end |
#metadata_only=(setting) ⇒ Object
This method is used to set the indicator for whether a backup stores only the database metadata.
Parameters
- setting
-
True to store only metadata, false otherwise.
1552 1553 |
# File 'lib/src.rb', line 1552 def (setting) end |
#non_transportable ⇒ Object
This method fetches the non-transportable setting for a Backup object.
1577 1578 |
# File 'lib/src.rb', line 1577 def non_transportable end |
#non_transportable=(setting) ⇒ Object
This method is used to set the indicator for whether backup generated by the task will be platform specific.
Parameters
- setting
-
True to generate a platform specific backup, false otherwise.
1588 1589 |
# File 'lib/src.rb', line 1588 def non_transportable=(setting) end |