Method: Rubyfb::Database.create
- Defined in:
- lib/src.rb
.create(file, user, password, size = 1024, set = nil) ⇒ Object
This method can be used to programmatically created a database file. If successful this method returns a Database object.
Parameters
- file
-
A string containing the path and name of the database file to be created.
- user
-
A string containing the user name that will be used in creating the file.
- password
-
A string containing the user password that will be used in creating the file.
- size
-
The page size setting to be used with the new database file. This should be 1024, 2048, 4096 or 8192. Defaults to 1024.
- set
-
The name of the default character set to be assigned to the new database file. If this parameter is specifed then the Database object created by the call will use it to whenever a connection request is made. Defaults to nil.
Exceptions
- Exception
-
Generated whenever an invalid parameter is specified or a problem occurs creating the database file.
147 148 |
# File 'lib/src.rb', line 147 def Database.create(file, user, password, size=1024, set=nil) end |