Method: Rubyfb::Generator#next
- Defined in:
- lib/src.rb
#next(step) ⇒ Object
This method fetches the next value, depending on a specified increment, from a generator.
Parameters
- step
-
The step interval to be applied to the generator to obtain the next value.
Exceptions
- Exception
-
Generated whenever a problem occurs accessing the database generator.
1267 1268 |
# File 'lib/src.rb', line 1267 def next(step) end |