Method: Rubyfb::Row#column_scale
- Defined in:
-
lib/src.rb,
lib/row.rb
This method fetches the scale associated with a specified column within a row of data. See the documentation of ResultSet#column_scale for details.
A reference to the column number to fetch the details for. Column numbers start at zero.
990 991 992 |
# File 'lib/src.rb', line 990 def column_scale(idx) @metadata[get_index(idx)].scale end |